==> scalarx_2.10-0.2.1-JS.jar: rx/ops/0003-Delay.js <==
/** @constructor */
ScalaJS.c.rx_ops_Delay = (function() {
  ScalaJS.c.rx_core_Dynamic.call(this);
  this.source$2 = null;
  this.delay$2 = null;
  this.scheduler$2 = null;
  this.ex$2 = null
});
ScalaJS.c.rx_ops_Delay.prototype = new ScalaJS.inheritable.rx_core_Dynamic();
ScalaJS.c.rx_ops_Delay.prototype.constructor = ScalaJS.c.rx_ops_Delay;
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$1) {
  return ScalaJS.c.rx_core_Dynamic.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set.call(this, incoming, evidence$1)
});
ScalaJS.c.rx_ops_Delay.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$2) {
  this.scheduler$2.scheduleOnce__Lscala_concurrent_duration_FiniteDuration__Lscala_Function0__Lscala_concurrent_ExecutionContext__V(this.delay$2, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(arg$outer, incoming$2, evidence$2$1) {
    return (function() {
      if ((!ScalaJS.anyRefEqEq(arg$outer.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming$2, evidence$2$1), ScalaJS.modules.scala_collection_immutable_Nil()))) {
        return arg$outer.propagate__Lrx_core_Propagator__O(evidence$2$1)
      } else {
        return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
      }
    })
  })(this, incoming, evidence$2)), this.ex$2);
  return ScalaJS.modules.scala_Predef().Set__Lscala_collection_immutable_Set$().empty__Lscala_collection_immutable_Set()
});
ScalaJS.c.rx_ops_Delay.prototype.level__J = (function() {
  return this.source$2.level__J().$$plus__Lscala_scalajs_runtime_Long__Lscala_scalajs_runtime_Long(ScalaJS.modules.scala_scalajs_runtime_Long().fromInt__I__Lscala_scalajs_runtime_Long(1))
});
ScalaJS.c.rx_ops_Delay.prototype.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext = (function(source, delay, scheduler, ex) {
  this.source$2 = source;
  this.delay$2 = delay;
  this.scheduler$2 = scheduler;
  this.ex$2 = ex;
  ScalaJS.c.rx_core_Dynamic.prototype.init___Lscala_Function0__T.call(this, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(source$2) {
    return (function() {
      return source$2.apply__O()
    })
  })(source)), ("Delayed " + source.name__T()));
  return this
});
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping = (function(arg$1, arg$2) {
  return this.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(arg$1, arg$2)
});
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__ = (function(incoming, evidence$1) {
  return this.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming, evidence$1)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Delay = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Delay.prototype = ScalaJS.c.rx_ops_Delay.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Delay = (function(arg$1, arg$2, arg$3, arg$4) {
  ScalaJS.c.rx_ops_Delay.call(this);
  return this.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext(arg$1, arg$2, arg$3, arg$4)
});
ScalaJS.classes.rx_ops_Delay.prototype = ScalaJS.c.rx_ops_Delay.prototype;
ScalaJS.is.rx_ops_Delay = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Delay)))
});
ScalaJS.as.rx_ops_Delay = (function(obj) {
  if ((ScalaJS.is.rx_ops_Delay(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Delay")
  }
});
ScalaJS.isArrayOf.rx_ops_Delay = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Delay)))
});
ScalaJS.asArrayOf.rx_ops_Delay = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Delay(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Delay;", depth)
  }
});
ScalaJS.data.rx_ops_Delay = new ScalaJS.ClassTypeData({
  rx_ops_Delay: 0
}, false, "rx.ops.Delay", ScalaJS.data.rx_core_Dynamic, {
  rx_ops_Delay: 1,
  rx_core_Dynamic: 1,
  rx_ops_Spinlock: 1,
  rx_ops_Incrementing: 1,
  rx_core_Rx: 1,
  rx_core_Reactor: 1,
  rx_core_Emitter: 1,
  rx_core_Node: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Delay.prototype.$classData = ScalaJS.data.rx_ops_Delay;
//@ sourceMappingURL=0003-Delay.js.map

==> scalarx_2.10-0.2.2-JS.jar: rx/ops/0003-Delay.js <==
/** @constructor */
ScalaJS.c.rx_ops_Delay = (function() {
  ScalaJS.c.rx_core_Dynamic.call(this);
  this.source$2 = null;
  this.delay$2 = null;
  this.scheduler$2 = null;
  this.ex$2 = null
});
ScalaJS.c.rx_ops_Delay.prototype = new ScalaJS.inheritable.rx_core_Dynamic();
ScalaJS.c.rx_ops_Delay.prototype.constructor = ScalaJS.c.rx_ops_Delay;
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$1) {
  return ScalaJS.c.rx_core_Dynamic.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set.call(this, incoming, evidence$1)
});
ScalaJS.c.rx_ops_Delay.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$2) {
  this.scheduler$2.scheduleOnce__Lscala_concurrent_duration_FiniteDuration__Lscala_Function0__Lscala_concurrent_ExecutionContext__V(this.delay$2, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(arg$outer, incoming$2, evidence$2$1) {
    return (function() {
      if ((!ScalaJS.anyRefEqEq(arg$outer.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming$2, evidence$2$1), ScalaJS.modules.scala_collection_immutable_Nil()))) {
        return arg$outer.propagate__Lrx_core_Propagator__O(evidence$2$1)
      } else {
        return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
      }
    })
  })(this, incoming, evidence$2)), this.ex$2);
  return ScalaJS.modules.scala_Predef().Set__Lscala_collection_immutable_Set$().empty__Lscala_collection_immutable_Set()
});
ScalaJS.c.rx_ops_Delay.prototype.level__J = (function() {
  return this.source$2.level__J().$$plus__Lscala_scalajs_runtime_Long__Lscala_scalajs_runtime_Long(ScalaJS.modules.scala_scalajs_runtime_Long().fromInt__I__Lscala_scalajs_runtime_Long(1))
});
ScalaJS.c.rx_ops_Delay.prototype.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext = (function(source, delay, scheduler, ex) {
  this.source$2 = source;
  this.delay$2 = delay;
  this.scheduler$2 = scheduler;
  this.ex$2 = ex;
  ScalaJS.c.rx_core_Dynamic.prototype.init___Lscala_Function0__T.call(this, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(source$2) {
    return (function() {
      return source$2.apply__O()
    })
  })(source)), ("Delayed " + source.name__T()));
  return this
});
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping = (function(arg$1, arg$2) {
  return this.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(arg$1, arg$2)
});
ScalaJS.c.rx_ops_Delay.prototype.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__ = (function(incoming, evidence$1) {
  return this.rx$ops$Delay$$super$ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming, evidence$1)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Delay = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Delay.prototype = ScalaJS.c.rx_ops_Delay.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Delay = (function(arg$1, arg$2, arg$3, arg$4) {
  ScalaJS.c.rx_ops_Delay.call(this);
  return this.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext(arg$1, arg$2, arg$3, arg$4)
});
ScalaJS.classes.rx_ops_Delay.prototype = ScalaJS.c.rx_ops_Delay.prototype;
ScalaJS.is.rx_ops_Delay = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Delay)))
});
ScalaJS.as.rx_ops_Delay = (function(obj) {
  if ((ScalaJS.is.rx_ops_Delay(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Delay")
  }
});
ScalaJS.isArrayOf.rx_ops_Delay = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Delay)))
});
ScalaJS.asArrayOf.rx_ops_Delay = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Delay(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Delay;", depth)
  }
});
ScalaJS.data.rx_ops_Delay = new ScalaJS.ClassTypeData({
  rx_ops_Delay: 0
}, false, "rx.ops.Delay", ScalaJS.data.rx_core_Dynamic, {
  rx_ops_Delay: 1,
  rx_core_Dynamic: 1,
  rx_core_Spinlock: 1,
  rx_core_Incrementing: 1,
  rx_core_Rx: 1,
  rx_core_Reactor: 1,
  rx_core_Emitter: 1,
  rx_core_Node: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Delay.prototype.$classData = ScalaJS.data.rx_ops_Delay;
//@ sourceMappingURL=0003-Delay.js.map
